@@ -22,10 +22,11 @@
      * Size units, e.g., Ki, Mi
 """
 
+# isort: STDLIB
 import abc
-
 from numbers import Rational
 
+# isort: FIRSTPARTY
 import justbases
 
 from ._errors import RangeValueError
@@ -33,8 +34,9 @@ from ._errors import RangeValueError
 RoundingMethods = justbases.RoundingMethods
 
 
-class Unit():
+class Unit:
     """ Class to encapsulate unit information. """
+
     # pylint: disable=too-few-public-methods
 
     def __init__(self, factor, prefix, abbr):
@@ -44,19 +46,18 @@ class Unit():
 
     def __str__(self):
         return self.abbr + "B"
+
     __repr__ = __str__
 
     # pylint: disable=protected-access
     factor = property(lambda s: s._factor, doc="numeric multiple of bytes")
-    abbr = property(
-       lambda s: s._abbr,
-       doc="abbreviation for unit, precedes 'B'"
-    )
+    abbr = property(lambda s: s._abbr, doc="abbreviation for unit, precedes 'B'")
     prefix = property(lambda s: s._prefix, doc="prefix for 'bytes'")
 
     def __int__(self):
         return self.factor
 
+
 B = Unit(1, "", "")
 """ The universal unit, bytes. """
 
@@ -65,6 +66,7 @@ class Units(metaclass=abc.ABCMeta):
     """
     Generic class for units.
     """
+
     # pylint: disable=too-few-public-methods
 
     FACTOR = abc.abstractproperty(doc="factor for each unit")
@@ -88,11 +90,7 @@ class Units(metaclass=abc.ABCMeta):
         :param int exponent: the exponent, 0 <= exponent < len(UNITS())
         """
         if exponent < 0 or exponent > cls.max_exponent():
-            raise RangeValueError(
-                exponent,
-                "exponent",
-                "no corresponding unit"
-            )
+            raise RangeValueError(exponent, "exponent", "no corresponding unit")
         if exponent == 0:
             return B
 
@@ -113,6 +111,7 @@ class Units(metaclass=abc.ABCMeta):
 
 class DecimalUnits(Units):
     """ Class to store decimal unit constants. """
+
     # pylint: disable=invalid-name
     # pylint: disable=too-few-public-methods
 
@@ -132,6 +131,7 @@ class DecimalUnits(Units):
 
 class BinaryUnits(Units):
     """ Class to store binary unit constants. """
+
     # pylint: disable=too-few-public-methods
 
     FACTOR = 2 ** 10
@@ -152,6 +152,7 @@ def UNITS():
     """ All unit constants. """
     return [B] + BinaryUnits.UNITS() + DecimalUnits.UNITS()
 
+
 ROUNDING_METHODS = RoundingMethods.METHODS
 
 PRECISE_NUMERIC_TYPES = (int, Rational)
